@@ -6,7 +6,7 @@ from wowpy.livestreams import LiveStream
 
 @pytest.fixture
 def live_stream_data():
-    with open('tests/fixtures/single_simplified_output_spec.json') as json_file:
+    with open('tests/fixtures/spec_one_output_template_full.json') as json_file:
         specification = json.load(json_file)
     live_stream_data = {'live_stream': specification['live_stream']['parameters']}
     live_stream_data['live_stream']['name'] = specification['name']
