@@ -20,4 +20,7 @@ logger = Logger('')
 logger.setLevel(loglevel)
 ch = logging.StreamHandler()
 ch.setLevel(loglevel)
-logger.addHandler(ch)
\ No newline at end of file
+logger.addHandler(ch)
+
+# Testing
+SKIP_REAL = os.getenv('SKIP_REAL', True)
\ No newline at end of file
