@@ -42,7 +42,9 @@ TRANSCODER_SCHEMA = Schema({
         ]
     ),
     Required('parameters'): { # key is empty
-        Required('idle_timeout', default=0): All(int, Range(min=0))
+        Required('idle_timeout'): All(int, Range(min=0)),
+        Required('buffer_size'): All(int, Range(min=0)),
+        Required('low_latency'): All(bool)
     }
 })
 
@@ -79,7 +81,7 @@ CUSTOM_TARGET_SCHEMA = Schema({
         Required('stream_name'): All(str, Length(min=0)),
         Required('use_https', default=True): All(bool)
     },
-    Required('properties'):
+    'properties':
         All(
             [
                 {
